==> huaweicloudsdkcbr-3.1.63-py2.py3-none-any.whl: huaweicloudsdkcbr/v1/model/remove_agent_path_response.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class RemoveAgentPathResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'removed': 'list[str]',
        'not_existed': 'list[str]'
    }

    attribute_map = {
        'removed': 'removed',
        'not_existed': 'not_existed'
    }

    def __init__(self, removed=None, not_existed=None):
        """RemoveAgentPathResponse

        The model defined in huaweicloud sdk

        :param removed: 移除的路径列表 
        :type removed: list[str]
        :param not_existed: 不存在的路径
        :type not_existed: list[str]
        """
        
        super(RemoveAgentPathResponse, self).__init__()

        self._removed = None
        self._not_existed = None
        self.discriminator = None

        if removed is not None:
            self.removed = removed
        if not_existed is not None:
            self.not_existed = not_existed

    @property
    def removed(self):
        """Gets the removed of this RemoveAgentPathResponse.

        移除的路径列表 

        :return: The removed of this RemoveAgentPathResponse.
        :rtype: list[str]
        """
        return self._removed

    @removed.setter
    def removed(self, removed):
        """Sets the removed of this RemoveAgentPathResponse.

        移除的路径列表 

        :param removed: The removed of this RemoveAgentPathResponse.
        :type removed: list[str]
        """
        self._removed = removed

    @property
    def not_existed(self):
        """Gets the not_existed of this RemoveAgentPathResponse.

        不存在的路径

        :return: The not_existed of this RemoveAgentPathResponse.
        :rtype: list[str]
        """
        return self._not_existed

    @not_existed.setter
    def not_existed(self, not_existed):
        """Sets the not_existed of this RemoveAgentPathResponse.

        不存在的路径

        :param not_existed: The not_existed of this RemoveAgentPathResponse.
        :type not_existed: list[str]
        """
        self._not_existed = not_existed

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RemoveAgentPathResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkcbr-3.1.157-py2.py3-none-any.whl: huaweicloudsdkcbr/v1/model/remove_agent_path_response.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class RemoveAgentPathResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'removed': 'list[str]',
        'not_existed': 'list[str]'
    }

    attribute_map = {
        'removed': 'removed',
        'not_existed': 'not_existed'
    }

    def __init__(self, removed=None, not_existed=None):
        r"""RemoveAgentPathResponse

        The model defined in huaweicloud sdk

        :param removed: 移除的路径列表 
        :type removed: list[str]
        :param not_existed: 不存在的路径
        :type not_existed: list[str]
        """
        
        super(RemoveAgentPathResponse, self).__init__()

        self._removed = None
        self._not_existed = None
        self.discriminator = None

        if removed is not None:
            self.removed = removed
        if not_existed is not None:
            self.not_existed = not_existed

    @property
    def removed(self):
        r"""Gets the removed of this RemoveAgentPathResponse.

        移除的路径列表 

        :return: The removed of this RemoveAgentPathResponse.
        :rtype: list[str]
        """
        return self._removed

    @removed.setter
    def removed(self, removed):
        r"""Sets the removed of this RemoveAgentPathResponse.

        移除的路径列表 

        :param removed: The removed of this RemoveAgentPathResponse.
        :type removed: list[str]
        """
        self._removed = removed

    @property
    def not_existed(self):
        r"""Gets the not_existed of this RemoveAgentPathResponse.

        不存在的路径

        :return: The not_existed of this RemoveAgentPathResponse.
        :rtype: list[str]
        """
        return self._not_existed

    @not_existed.setter
    def not_existed(self, not_existed):
        r"""Sets the not_existed of this RemoveAgentPathResponse.

        不存在的路径

        :param not_existed: The not_existed of this RemoveAgentPathResponse.
        :type not_existed: list[str]
        """
        self._not_existed = not_existed

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RemoveAgentPathResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
